@@ -5,7 +5,7 @@ use Encode qw();
 use HTML::Entities;
 use Test::WWW::Mechanize;
 use base qw(Test::WWW::Mechanize);
-our $VERSION = "0.38";
+our $VERSION = "0.39";
 my $Test = Test::Builder->new();
 
 # the reason for the auxiliary package is that both WWW::Mechanize and
@@ -15,6 +15,12 @@ sub _make_request {
     my ( $self, $request ) = @_;
     $self->cookie_jar->add_cookie_header($request) if $self->cookie_jar;
 
+    unless ( $request->uri->as_string =~ m{^/}
+        || $request->uri->host eq 'localhost' )
+    {
+        return $self->SUPER::_make_request($request);
+    }
+
     $request->authorization_basic(
         LWP::UserAgent->get_basic_credentials(
             undef, "Basic", $request->uri
@@ -132,6 +138,10 @@ two lines of code do exactly the same thing:
   $mech->get_ok('/action');
   $mech->get_ok('http://localhost/action');
 
+Links which do not begin with / or are not for localhost are handled
+as normal Web requests - this is handy if you have an external 
+single sign-on system.
+
 You can also test a remote server by setting the environment variable
 CATALYST_SERVER, for example:
 
@@ -330,7 +340,7 @@ Leon Brocard, C<< <acme@astray.com> >>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005, Leon Brocard
+Copyright (C) 2005-7, Leon Brocard
 
 This module is free software; you can redistribute it or modify it
 under the same terms as Perl itself.
